==> embrace-android-sdk-3.4.0-sources.jar: io/embrace/android/embracesdk/NetworkLoggingService.java <==
package io.embrace.android.embracesdk;

import java.util.List;

/**
 * Logs network calls made by the application. The Embrace SDK intercepts the calls and reports
 * them to the API.
 */
public interface NetworkLoggingService {

    /**
     * Get the calls and counts of network calls (which exceed the limit) within the specified time
     * range.
     *
     * @param startTime     the start time
     * @param lastKnownTime the end time
     * @return
     */
    NetworkSessionV2 getNetworkSession(long startTime, long lastKnownTime);

    /**
     * Get all of the network calls which occurred within the specified time range.
     *
     * @param startTime the start time of the range
     * @param endTime   the end time of the range
     * @return the list of network calls
     */
    List<NetworkCallV2> getNetworkCalls(long startTime, long endTime);

    /**
     * Logs a HTTP network call.
     *
     * @param url           the URL being called
     * @param httpMethod    the HTTP method
     * @param statusCode    the status code from the response
     * @param startTime     the start time of the request
     * @param endTime       the end time of the request
     * @param bytesSent     the number of bytes sent
     * @param bytesReceived the number of bytes received
     * @param traceId optional trace ID that can be used to trace a particular request
     */
    void logNetworkCall(
            String url,
            String httpMethod,
            Integer statusCode,
            long startTime,
            long endTime,
            Long bytesSent,
            Long bytesReceived,
            String traceId);

    /**
     * Logs an exception which occurred when attempting to make a network call.
     *
     * @param url          the URL being called
     * @param httpMethod   the HTTP method
     * @param startTime    the start time of the request
     * @param endTime      the end time of the request
     * @param errorType    the type of error being thrown
     * @param errorMessage the error message
     * @param traceId optional trace ID that can be used to trace a particular request
     */
    void logNetworkError(
            String url,
            String httpMethod,
            long startTime,
            long endTime,
            String errorType,
            String errorMessage,
            String traceId);
}

==> embrace-android-sdk-4.5.4-sources.jar: io/embrace/android/embracesdk/NetworkLoggingService.java <==
package io.embrace.android.embracesdk;

import java.util.List;

import androidx.annotation.NonNull;

/**
 * Logs network calls made by the application. The Embrace SDK intercepts the calls and reports
 * them to the API.
 */
public interface NetworkLoggingService {

    /**
     * Get the calls and counts of network calls (which exceed the limit) within the specified time
     * range.
     *
     * @param startTime     the start time
     * @param lastKnownTime the end time
     * @return
     */
    NetworkSessionV2 getNetworkSession(long startTime, long lastKnownTime);

    /**
     * Get all of the network calls which occurred within the specified time range.
     *
     * @param startTime the start time of the range
     * @param endTime   the end time of the range
     * @return the list of network calls
     */
    List<NetworkCallV2> getNetworkCalls(long startTime, long endTime);

    /**
     * Logs a HTTP network call.
     *
     * @param url           the URL being called
     * @param httpMethod    the HTTP method
     * @param statusCode    the status code from the response
     * @param startTime     the start time of the request
     * @param endTime       the end time of the request
     * @param bytesSent     the number of bytes sent
     * @param bytesReceived the number of bytes received
     * @param traceId optional trace ID that can be used to trace a particular request
     */
    void logNetworkCall(
            @NonNull String url,
            @NonNull String httpMethod,
            int statusCode,
            long startTime,
            long endTime,
            long bytesSent,
            long bytesReceived,
            String traceId);

    /**
     * Logs an exception which occurred when attempting to make a network call.
     *
     * @param url          the URL being called
     * @param httpMethod   the HTTP method
     * @param startTime    the start time of the request
     * @param endTime      the end time of the request
     * @param errorType    the type of error being thrown
     * @param errorMessage the error message
     * @param traceId optional trace ID that can be used to trace a particular request
     */
    void logNetworkError(
            @NonNull String url,
            @NonNull String httpMethod,
            long startTime,
            long endTime,
            String errorType,
            String errorMessage,
            String traceId);
}
